.. _asdf-astropy_manifest:

=====================
asdf-astropy Manifest
=====================

Documentation of the ASDF manifest for **asdf-astropy** can be found below:

.. literalinclude:: ../../asdf_astropy/resources/manifests/astropy-1.0.0.yaml
   :language: yaml
